@@ -37,20 +37,25 @@ class Writer:
     
     Parameters
     ----------
-    :log_dir: Path directory où les fichiers de communication du programme 
-        vers TensorBoard seront storé. Par défaut 
-        chemin_courant/RUN/current_datetime_hostname qui change avec chaque 
+    log_dir : Optional[str]
+        Path directory où les fichiers de communication du programme vers
+        TensorBoard seront storé. Par défaut 
+        chemin_courant/RUN/current_datetime_hostname qui change avec chaque
         run.
-    :comment: Ajoute un suffix au log_dir. Si log_dir est non None cet 
-        argument ne sera pas pris en compte.
-    :purge_step: Si le logging crache à l'étape T+X et redémarre à l'étape 
-        T, tout événement qui ont un gloabl_step plus grand ou égual à X 
-        seront purgé et caché dans TensorBoard.
-    :max_queue: Taille de la queue d'évenement à stocker avec de pousser (add)
-        vers le disque dur.
-    :flush_secs: Temps de refraichissement ver les logs sur le disque dure.
-    :filename_suffix: Suffix ajouter à tous les événements dans le répertoire
-        log_dir.
+    comment : str (='')
+        Ajoute un suffix au log_dir. Si log_dir est non None cet argument ne
+        sera pas pris en compte.
+    purge_step : Optional[int]
+        Si le logging crache à l'étape T+X et redémarre à l'étape T, tout
+        événement qui ont un gloabl_step plus grand ou égual à X seront purgé
+        et caché dans TensorBoard.
+    max_queue : int (=10)
+        Taille de la queue d'évenement à stocker avec de pousser (add) vers
+        le disque dur.
+    flush_secs : int (=120)
+        Temps de refraichissement ver les logs sur le disque dure.
+    filename_suffix : str (='')
+        Suffix ajouter à tous les événements dans le répertoire log_dir.
     """
     log_dir: Optional[str]=None
     comment: str=''
